#[repr(C)]pub struct ControlSetup {
pub request_type: u8,
pub request: u8,
pub value: u16,
pub index: u16,
pub len: u16,
}Expand description
Any Serialization or deserialization of this struct should be careful to make sure the u16s
are in Little Endian for the wire and Host Endian at all other times.
Fields
request_type: u8request: u8value: u16index: u16len: u16Implementations
Sourceimpl ControlSetup
impl ControlSetup
pub const SIZE: usize
Sourcepub fn serialize(self, buf: &mut [u8])
pub fn serialize(self, buf: &mut [u8])
Taste Host-Endian ControlSetup and serializes it in Little-Endian
pub fn deserialize(buf: &[u8]) -> ControlSetup